@@ -13,8 +13,8 @@
 
 __name__ = 'corpwechatbot'
 __description__ = 'python interface for corpwechat message sending'
-__url__ = 'https://github.com/GentleCP/corpwechat-bot'
-__version__= '0.6.1'
+__url__ = 'https://github.com/GentleCP/corpwechatbot'
+__version__ = '0.6.2'
 __author__ = 'GentleCP'
 __author_email__ = 'me@gentlecp.com'
-__license__ = 'GPL v3'
\ No newline at end of file
+__license__ = 'GPL v3'
